@@ -1,4 +1,4 @@
-from typing import Type
+from typing import Container, Type
 
 from pydantic import BaseConfig, BaseModel, create_model
 from sqlalchemy.inspection import inspect
@@ -9,7 +9,9 @@ class OrmConfig(BaseConfig):
     orm_mode = True
 
 
-def sqlalchemy_to_pydantic(db_model: Type) -> Type[BaseModel]:
+def sqlalchemy_to_pydantic(
+    db_model: Type, *, config: Type = OrmConfig, exclude: Container[str] = []
+) -> Type[BaseModel]:
     mapper = inspect(db_model)
     fields = {}
     for attr in mapper.attrs:
@@ -18,11 +20,13 @@ def sqlalchemy_to_pydantic(db_model: Type) -> Type[BaseModel]:
                 column = attr.columns[0]
                 python_type = column.type.python_type
                 name = attr.key
-                default = column.default
-                if default is None and not column.nullable:
+                if name in exclude:
+                    continue
+                default = None
+                if column.default is None and not column.nullable:
                     default = ...
                 fields[name] = (python_type, default)
     pydantic_model = create_model(
-        db_model.__name__, __config__=OrmConfig, **fields  # type: ignore
+        db_model.__name__, __config__=config, **fields  # type: ignore
     )
     return pydantic_model
